
---

## answer:q1

### Integer answer

1 / 1

### Correct answer

3 / 3

---

## answer:q2

### Presence of docstring

Your variable get_remainder has value <function get_remainder at 0x1071934c0>.
 You did not include a docstring. This is important to help document your code.


It is done  using triple quotation marks. For example:

def get_remainder(m, n):
    """
    This function returns the remainder of m when dividing by n
    """
    ...

Using that it's possible to access the docstring,
one way to do this is to type: `get_remainder?`
(which only works in Jupyter) or help(get_remainder).

We can also comment code using `#` but this is completely
ignored by Python so cannot be accessed in the same way.



0 / 1

### Correct answer

6 / 6
